@@ -523,24 +523,30 @@ a
 				input: tu.PrepareMarkdownFile(t)},
 			out: out{
 				output: strings.TrimPrefix(`
-a
-├── i
-│   ├── u
-│   │   ├── k
-│   │   └── kk
-│   └── t
-├── e
-│   └── o
-└── g
-a
-├── i
-│   ├── u
-│   │   ├── k
-│   │   └── kk
-│   └── t
-├── e
-│   └── o
-└── g
+Artiodactyla
+├── Artiofabula
+│   ├── Cetruminantia
+│   │   ├── Whippomorpha
+│   │   │   ├── Hippopotamidae
+│   │   │   └── Cetacea
+│   │   └── Ruminantia
+│   └── Suina
+└── Tylopoda
+Carnivora
+├── Feliformia
+└── Caniformia
+    ├── Canidae
+    └── Arctoidea
+        ├── Ursidae
+        └── x
+            ├── Pinnipedia
+            └── Musteloidea
+                ├── Ailuridae
+                └── x
+                    ├── Mephitidae
+                    └── x
+                        ├── Procyonidae
+                        └── Mustelidae
 `, "\n"),
 				err: nil,
 			},
